@@ -1,5 +1,7 @@
+# -*- coding: UTF-8 -*-
 from .android_string import ordered_set, string2csv
 from .aloon import main
+from .simple_parsing import *
 
 __all__ = [
     "ordered_set",
